# PySCeS - the Python Simulator for Cellular Systems

PySCeS was originally developed by the Triple-J Group for Molecular 
Cell Physiology at Stellenbosch University in order to try to model and understand the 
complex processes and systems which make up the living cell. The project is 
maintained by Brett Olivier (AIMMS, Vrije Universiteit Amsterdam) and Johann Rohwer 
(Laboratory for Molecular Systems Biology, Stellenbosch University).

PySCeS features, amongst other things:
- A text-based model description language.
- A structural analysis module.
- Integrators for time simulation.
- Non-linear solvers for steady-state analysis.
- A module for performing Metabolic Control Analysis.
- A bifurcation module for systems which exhibit multiple steady states.
- A variety of extra utilities for parameter scans, data output and plotting.
- A dynamic module loading framework.
- Systems Biology Markup Language (SBML) import and export capability.